@@ -60,6 +60,7 @@ class Times(BaseModel):
     time_received: datetime
     time_done: datetime
     secs_took: float
+    get_size_time: float = None
 
 
 class Call(DateModel):
@@ -67,6 +68,7 @@ class Call(DateModel):
     response: Response = None
     error: Error = None
     times: Times
+    message: str = None
 
     class Meta:
         collection_name = "_calls"
@@ -228,9 +230,46 @@ async def make_call_from_request_and_response(
         times=Times(**times_dict),
     )
 
-    print("call size", sys.getsizeof(call))
-    print("response_obj size", sys.getsizeof(response_obj))
-    print("request_obj size", sys.getsizeof(request_obj))
-    print("error_obj size", sys.getsizeof(error_obj))
+    DYNAMO_DB_MAX_SIZE = 990_000
+
+    def size_under(obj, seen=None, max_size=DYNAMO_DB_MAX_SIZE):
+        """Recursively finds size of objects"""
+        size = sys.getsizeof(obj)
+        if seen is None:
+            seen = set()
+        obj_id = id(obj)
+        if obj_id in seen:
+            return 0
+        # Important mark as seen *before* entering recursion to gracefully handle
+        # self-referential objects
+        seen.add(obj_id)
+        if isinstance(obj, dict):
+            size += sum([size_under(v, seen) for v in obj.values()])
+            size += sum([size_under(k, seen) for k in obj.keys()])
+            if size > max_size:
+                return size
+        elif hasattr(obj, "__dict__"):
+            size += size_under(obj.__dict__, seen)
+            if size > max_size:
+                return size
+        elif hasattr(obj, "__iter__") and not isinstance(obj, (str, bytes, bytearray)):
+            size += sum([size_under(i, seen) for i in obj])
+            if size > max_size:
+                return size
+        return size
+
+    import time
+
+    start_size_time = time.time()
+    size_of_call = size_under(call)
+    size_time_took = time.time() - start_size_time
+    call.times.get_size_time = size_time_took
+    if size_of_call > DYNAMO_DB_MAX_SIZE:
+        print("size of call was", size_of_call)
+        if call.request:
+            call.request.body = None
+        if call.response:
+            call.response.body = None
+        call.message = f"Original size {size_of_call} was too big so cut out request and response body."
 
     save_call(call)
