@@ -50,9 +50,9 @@ def add_hello_world_testing_route(new_app):
     def read_root():
         print("hello world!")
         return {
-            "Hello": "Worlda!",
-            "cwd": Path.cwd(),
-            "dir": os.listdir(),
+            "Welcome": "!",
+            # "cwd": Path.cwd(),
+            # "dir": os.listdir(),
         }
 
 
